# Copyright (C) 2017-2022 Vanessa Sochat.

# This Source Code Form is subject to the terms of the
# Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
# with this file, You can obtain one at http://mozilla.org/MPL/2.0/.


__version__ = "0.1.18"
AUTHOR = "Vanessa Sochat"
AUTHOR_EMAIL = "vsoch@users.noreply.github.com"
NAME = "spython"
PACKAGE_URL = "https://github.com/singularityhub/singularity-cli"
KEYWORDS = "singularity python client (spython)"
DESCRIPTION = "Command line python tool for working with singularity."
LICENSE = "LICENSE"

INSTALL_REQUIRES = (("semver", {"min_version": "2.8.1"}),)

TESTS_REQUIRES = (("pytest", {"min_version": "4.6.2"}),)
